#ifndef MAINWINDOW_H
#define MAINWINDOW_H


#include "mainwindow.h"

#include <QMainWindow>
#include <QtCore>
#include <QToolBar>
#include <QMenuBar>
#include <QStatusBar>
#include <QAction>
#include <QDockWidget>

#include "../Models/videocontainer.h"
#include "../FrameViewer/frameviewer.h"
#include "../FrameNav/framenav.h"
#include "../TimeLine/timeline.h"

class MainWindowUI;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0, Qt::WindowFlags flags = 0);
    ~MainWindow();

    // ==== UI STUFF ====

    // ui components
public:
    QMenu* fileMenu;
    QMenu* frameMenu;
    QMenu* toolMenu;
    QMenu* windowsMenu;
    QMenu* helpMenu;

    QStatusBar* mainStatusBar;
    QToolBar* mainToolBar;

    FrameViewer* frameViewer;
    FrameNav* frameNav;
    TimeLine* timeLine;

    void recreateDataState();


    // ui functions
public slots:
    void reload();



    // ==== LOGIC STUFF ====

    // actions
public:
    QAction* actionNew;
    QAction* actionSave;
    QAction* actionOpen;
    QAction* actionClose;

    QAction* actionNextFrame;
    QAction* actionPrevFrame;

    QAction* actionLinearMorphing;
    QAction* actionInteractiveTracking;
    QAction* actionAutomaticTracking;
    QAction* actionExportXML;
    QAction* actionSegmentation;

    QAction* helpLicense;
    QAction* helpAbout;

public slots:
    void onActionNew();
    void onActionSave();
    void onActionOpen();
    void onActionClose();

    void onActionNextFrame();
    void onActionPrevFrame();

    void onActionLinearMorphing();
    void onActionInteractiveTracking();
    void onActionAutomaticTracking();
    void onActionExportXML();
    void onActionSegmentation();

    void onActionTmpDebugAction();

    void onActionHelpLicense();
    void onActionHelpAbout();

private:
    int breakFrame;

};

#endif // MAINWINDOW_H
